package
Version:
v0.1.39
Opens a new window with list of versions in this module.
Published: Apr 27, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Mode Mode `pkl:"mode"`
TreeRoot string `pkl:"treeRoot"`
}
const (
DynamicMode Mode = "dynamic"
EmbeddedMode Mode = "embedded"
RootMode Mode = "root"
)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.