Documentation
¶
Index ¶
- type CertEntry
- type CertType
- type Certificates
- func (c *Certificates) All() ([]*CertEntry, error)
- func (c *Certificates) Del(ski string) error
- func (c *Certificates) Get(ski string) (*CertEntry, error)
- func (c *Certificates) GetByFingerPrint(fingerprint string) (*CertEntry, error)
- func (c *Certificates) GetByPublisher(publisher string) ([]*CertEntry, error)
- func (c *Certificates) GetBySubject(subject string) ([]*CertEntry, error)
- func (c *Certificates) GetByType(ctype CertType) ([]*CertEntry, error)
- func (c *Certificates) Put(ski string, fingerprint string, subject string, publisher string, ...) error
- type KeyPairEntry
- type KeyPairs
- func (k *KeyPairs) All() ([]*KeyPairEntry, error)
- func (k *KeyPairs) Del(ski string) error
- func (k *KeyPairs) Get(ski string) (*KeyPairEntry, error)
- func (k *KeyPairs) GetByFingerPrint(fingerprint string) (*KeyPairEntry, error)
- func (k *KeyPairs) GetByPublisher(publisher string) ([]*KeyPairEntry, error)
- func (k *KeyPairs) GetBySubject(subject string) ([]*KeyPairEntry, error)
- func (k *KeyPairs) Put(ski string, fingerprint string, subject string, publisher string, cert []byte, ...) error
- type Pki
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CertEntry ¶
type Certificates ¶
type Certificates struct {
// contains filtered or unexported fields
}
func (*Certificates) All ¶
func (c *Certificates) All() ([]*CertEntry, error)
func (*Certificates) Del ¶
func (c *Certificates) Del(ski string) error
func (*Certificates) GetByFingerPrint ¶
func (c *Certificates) GetByFingerPrint(fingerprint string) (*CertEntry, error)
func (*Certificates) GetByPublisher ¶
func (c *Certificates) GetByPublisher(publisher string) ([]*CertEntry, error)
func (*Certificates) GetBySubject ¶
func (c *Certificates) GetBySubject(subject string) ([]*CertEntry, error)
type KeyPairEntry ¶
type KeyPairEntry struct {
SKI string `storm:"id"`
Fingerprint string `storm:"index"`
Subject string `storm:"index"`
Publisher string `storm:"index"`
Cert []byte
Key []byte
}
func (*KeyPairEntry) RSAKey ¶
func (k *KeyPairEntry) RSAKey() (*rsa.PrivateKey, error)
type KeyPairs ¶
type KeyPairs struct {
// contains filtered or unexported fields
}
func (*KeyPairs) All ¶
func (k *KeyPairs) All() ([]*KeyPairEntry, error)
func (*KeyPairs) GetByFingerPrint ¶
func (k *KeyPairs) GetByFingerPrint(fingerprint string) (*KeyPairEntry, error)
func (*KeyPairs) GetByPublisher ¶
func (k *KeyPairs) GetByPublisher(publisher string) ([]*KeyPairEntry, error)
func (*KeyPairs) GetBySubject ¶
func (k *KeyPairs) GetBySubject(subject string) ([]*KeyPairEntry, error)
Click to show internal directories.
Click to hide internal directories.